pm4py.statistics.sojourn\_time package
======================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.statistics.sojourn_time.log
   pm4py.statistics.sojourn_time.pandas

Module contents
---------------

.. automodule:: pm4py.statistics.sojourn_time
   :members:
   :undoc-members:
   :show-inheritance:
